Module t3

Module t3 

Trust Tensor (T3) Implementation

T3 is a 3-dimensional trust tensor whose root dimensions are nodes in an open-ended RDF sub-graph. Each root can have any number of sub-dimensions linked via web4:subDimensionOf. The scalar value at each root is the aggregate of its sub-graph.

Root Dimensions:

  1. Talent - natural aptitude and capability for a specific role
  2. Training - acquired expertise, certifications, and experience
  3. Temperament - behavioral consistency, reliability, ethical disposition

Formal ontology: web4-standard/ontology/t3v3-ontology.ttl

Structs

SubDimensionScore
Score data for a sub-dimension
T3
A 3-dimensional trust tensor with fractal sub-dimension support
TrustObservation
A trust observation to be recorded
TrustRelation
Trust relationship between two entities

Enums

TrustDimension
The three root dimensions of trust

Constants

T3_DIMENSIONS
Number of root dimensions in the trust tensor